==> nnim_electron_sdk-1.0.8.tgz: package/lib/windows/include/leigod-im-cross-sdk.h <==
#pragma once
#include <string>

#ifdef _WIN32
#ifdef IM_SDK_EXPORTS
#define LEIGOD_IM_SDK_API __declspec(dllexport)
#else
#define LEIGOD_IM_SDK_API __declspec(dllimport)
#endif
#else
#define LEIGOD_IM_SDK_API
#endif

#ifdef __cplusplus
extern "C" {
#endif

typedef struct {
	const char* str;
	size_t len;
} string_t;

//Ϣص
typedef void(*MSGCALLBACK)(int packet_type, int cmd_type, const string_t* belong_id, const string_t* channel_id, int remote_user_id, const string_t* msg, int msg_type, const string_t* session_id, int64_t msg_id, int64_t cmsg_id, void* user_data);

//֪ͨص
typedef void(*NOTIFYCALLBACK)(int packet_type, int cmd_type, const string_t* belong_id, int remote_user_id, const string_t* msg, const string_t* title, int msg_type, int notify_type, const string_t* session_id, int64_t msg_id, int64_t cmsg_id, void* user_data);

//¼ص
typedef void(*EVENTCALLBACK)(int packet_type, int cmd_type, const string_t* device_id, int status_code, int event_type, const string_t* session_id, int64_t msg_id, int64_t cmsg_id, const string_t* msg, int business_type, void* user_data);

//httpؽӿڻصûỰбʷϢбΪjsonӦuser_dataΪûԶ
typedef void(*HTTPCALLBACK)(const string_t* json_body, void* user_data);

//SDKʼ
LEIGOD_IM_SDK_API void SdkInit(const string_t& server_lsb_url, const string_t& server_lsb_port, const string_t& im_token, MSGCALLBACK msg_callback, NOTIFYCALLBACK notify_callback, EVENTCALLBACK event_callback, HTTPCALLBACK http_callback, void* user_data);

//¼ǳ
LEIGOD_IM_SDK_API void SdkLogin(const int& device_type, const int64_t& user_id, const string_t& laser_reg_id);
LEIGOD_IM_SDK_API void SdkLogout();

//
LEIGOD_IM_SDK_API void SdkPrivateChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_chat_id, const int& message_type);

//Ⱥ
LEIGOD_IM_SDK_API void SdkGroupChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkJoinGroup(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkDisbandGroup(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkCreateGroup(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);

//
LEIGOD_IM_SDK_API void SdkJoinVoiceRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkCloseVoiceRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkRemoveMembersVoiceRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkVoiceRoomChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);

//ɶԷ
LEIGOD_IM_SDK_API void SdkJoinPartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkClosePartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkCreatePartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkRemoveMembersPartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkPartyRoomChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);

//ϢأѶɾ
LEIGOD_IM_SDK_API void SdkImMessageAck(const int64_t& msg_id, const int64_t& cmsg_id, const string_t& session_id, const string_t& msg,int business_type);
LEIGOD_IM_SDK_API void SdkDeleteMsg(const int64_t& msg_id, const int64_t& cmsg_id, const string_t& session_id, const string_t& msg, int business_type);
LEIGOD_IM_SDK_API void SdkWithdrawnMsg(const int64_t& msg_id, const int64_t& cmsg_id, const string_t& session_id, const string_t& msg, int business_type);

//
LEIGOD_IM_SDK_API void SdkSubscribeGroup(const int64_t& subscribe_group_room_id, const string_t& subscribe_type, int64_t subscribe_uids[], int subscribe_uids_cnt);

//

//ȡûỰб
LEIGOD_IM_SDK_API void SdkGetUserSessionList(int64_t user_id);

//ȡʷϢб
LEIGOD_IM_SDK_API void SdkGetHistoryMsgList(int count, int sequence, const string_t& session_id);

#ifdef __cplusplus
}
#endif

==> nnim_electron_sdk-1.0.12.tgz: package/lib/windows/include/leigod-im-cross-sdk.h <==
#pragma once
#include <string>

#ifdef _WIN32
#ifdef IM_SDK_EXPORTS
#define LEIGOD_IM_SDK_API __declspec(dllexport)
#else
#define LEIGOD_IM_SDK_API __declspec(dllimport)
#endif
#else
#define LEIGOD_IM_SDK_API
#endif

#ifdef __cplusplus
extern "C" {
#endif

typedef struct {
	const char* str;
	size_t len;
} string_t;

enum class HttpReqType {
	E_Http_SessionList = 0,
	E_Http_MessageRecord = 1,
};

//Ϣص
typedef void(*MSGCALLBACK)(int packet_type, int cmd_type, const string_t* belong_id, const string_t* channel_id, int remote_user_id, const string_t* msg, int msg_type, const string_t* session_id, int64_t msg_id, int64_t cmsg_id, void* user_data);

//֪ͨص
typedef void(*NOTIFYCALLBACK)(int packet_type, int cmd_type, const string_t* belong_id, int remote_user_id, const string_t* msg, const string_t* title, int msg_type, int notify_type, const string_t* session_id, int64_t msg_id, int64_t cmsg_id, void* user_data);

//¼ص
typedef void(*EVENTCALLBACK)(int packet_type, int cmd_type, const string_t* device_id, int status_code, int event_type, const string_t* session_id, int64_t msg_id, int64_t cmsg_id, const string_t* msg, int business_type, void* user_data);

//httpؽӿڻصûỰбʷϢбΪjsonӦuser_dataΪûԶ
typedef void(*HTTPCALLBACK)(int req_type, const string_t* json_body, void* user_data);

//SDKʼ
LEIGOD_IM_SDK_API void SdkInit(const string_t& server_lsb_url, const string_t& server_lsb_port, const string_t& im_token, MSGCALLBACK msg_callback, NOTIFYCALLBACK notify_callback, EVENTCALLBACK event_callback, HTTPCALLBACK http_callback, void* user_data);

//¼ǳ
LEIGOD_IM_SDK_API void SdkLogin(const int& device_type, const int64_t& user_id, const string_t& laser_reg_id);
LEIGOD_IM_SDK_API void SdkLogout();

//
LEIGOD_IM_SDK_API void SdkPrivateChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_chat_id, const int& message_type);

//Ⱥ
LEIGOD_IM_SDK_API void SdkGroupChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkJoinGroup(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkDisbandGroup(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkCreateGroup(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& remote_group_chat_id, const int& message_type);

//
LEIGOD_IM_SDK_API void SdkJoinVoiceRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkCloseVoiceRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkRemoveMembersVoiceRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkVoiceRoomChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& voice_room_id, const int& message_type);

//ɶԷ
LEIGOD_IM_SDK_API void SdkJoinPartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkClosePartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkCreatePartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkRemoveMembersPartyRoom(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);
LEIGOD_IM_SDK_API void SdkPartyRoomChat(const string_t& belong_id, const string_t& channel_id, const string_t& msg, const int64_t& party_room_id, const int& message_type);

//ϢأѶɾ
LEIGOD_IM_SDK_API void SdkImMessageAck(const int64_t& msg_id, const int64_t& cmsg_id, const string_t& session_id, const string_t& msg,int business_type);
LEIGOD_IM_SDK_API void SdkDeleteMsg(const int64_t& msg_id, const int64_t& cmsg_id, const string_t& session_id, const string_t& msg, int business_type);
LEIGOD_IM_SDK_API void SdkWithdrawnMsg(const int64_t& msg_id, const int64_t& cmsg_id, const string_t& session_id, const string_t& msg, int business_type);

//
LEIGOD_IM_SDK_API void SdkSubscribeGroup(const int64_t& subscribe_group_room_id, const string_t& subscribe_type, int64_t subscribe_uids[], int subscribe_uids_cnt);

//

//ȡûỰб
LEIGOD_IM_SDK_API void SdkGetUserSessionList(int64_t user_id);

//ȡʷϢб
LEIGOD_IM_SDK_API void SdkGetHistoryMsgList(int count, int sequence, const string_t& session_id);

#ifdef __cplusplus
}
#endif
